<?php

/***************************************************************************************
 *											*
 *   	Copyright 2006 by Davide Simoncelli                                      	*
 *   	Email: netcelli_gentoo at users dot sourceforge dot net                      	*
 *                                                                         		*
 *   	This program is free software; you can redistribute it and/or			*
 *	modify it under the terms of the GNU General Public License			*
 *	as published by the Free Software Foundation; either version 2			*
 *	of the License, or (at your option) any later version.				*
 *											*
 *	This program is distributed in the hope that it will be useful,			*
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of			*
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the			*
 *	GNU General Public License for more details.					*
 *											*
 *	You should have received a copy of the GNU General Public License		*
 *	along with this program; if not, write to the Free Software			*
 *	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.	*	
 *											*
 ****************************************************************************************/

/**
 *	@name Utility
 *	@static
 * 	@since VHCP 1.7
 * 	@package VHCP
*/

class Utility
{
	/**
    * Send a raw HTTP header
    * @param String $url 
   	* @access public
   	*/
	
	public function redirect($url="./")
	{
		header("Location: $url");
		die("<a href=\"$url\">$url</a>");
	}
	
	/**
    * Show an error message
    * @param string $errstr the message to show
    * @param  boolean $die
   	* @access public
   	* @return bool
   	*/
	
	public function error($errstr,$die=false)
	{
		echo "<div align=\"center\"><br><div align=\"center\" style=\"font-family:verdana;font-size:11px;border:2px dashed #CC3333;padding:3px;margin:3px;background-color:F6F6F6;width:300px;\"><strong>Error</strong><br />$errstr</div>";
		if($die)
		{
			die();
		}
		return false;
	}
	
	/**
    * Show a successful message
    * @param string $goodstr the message to show
    * @param bool $die
   	* @access public
   	* @return bool
   	*/
	
	public function good($goodstr,$die=false)
	{
		echo "<div align=\"center\"><br><div style=\"font-family:verdana;font-size:11px;border:2px dashed #47BD22;padding:3px;margin:3px;background-color:F6F6F6;width:300px;\"><strong>Ok</strong><br />$goodstr</div>";
		if($die)
		{
			die();
		}
		return false;
	}
		
	/**
    * Trim text at specified lenght
    * @param string $txt the string to modify
    * @param integer $lenght the max lenght of the string
   	* @access public
   	* @return string
   	*/
	
	public function trimText($txt,$lenght=30)
	{
		if(strlen($txt)>$lenght)
		{
			return substr($txt,0,$lenght) . "...";
		}
		else
		{
			return $txt;
		}
	}
	
	/**
    * Wraps a string to a given number of characters using a string break character
    * @param string $txt the string to modify
    * @param integer $lenght the max lenght of the string
    * @param string $break the breaker
    * @param integer $cut
   	* @return string
   	* @access public
   	*/
	
	public function wordwrap($txt,$lenght=15,$break="\n")
	{
		if(strlen($txt)>$lenght)
		{
			return wordwrap($txt,$lenght,"<br>",1) . "";
		}
		else
		{
			return $txt;
		}
	}
	
	/**
    * Print the main menu with class-option
    * @return void
    * @access public
   	*/
	
	public function printMenu()
	{
		$menu[0] = array("start"=>"Home","stats"=>"Stats","iplog"=>"IP-Log","login"=>"Login");
		$menu[1] = array("start"=>"Home","stats"=>"Stats","iplog"=>"IP-Log","logout"=>"Log out");
		$menu[2] = array("start"=>"Home","stats"=>"Stats","filetrigger"=>"File Trigger","logout"=>"Log out");
		$menu[3] = array("start"=>"Home","kicklist"=>"Kick List","banlist"=>"Ban List","unbanlist"=>"Unban List","iplog"=>"IP-Log","stats"=>"Stats","reglist"=>"Accounts","logout"=>"Log out");
		$menu[4] = array("start"=>"Home","kicklist"=>"Kick List","banlist"=>"Ban List","unbanlist"=>"Unban List","iplog"=>"IP-Log","stats"=>"Stats","reglist"=>"Accounts","logout"=>"Log out");
		$menu[5] = array("start"=>"Home","info"=>"Info","kicklist"=>"Kick List","banlist"=>"Ban List","unbanlist"=>"Unban List","iplog"=>"IP-Log","stats"=>"Stats","filetrigger"=>"File Trigger","conntype"=>"Conn Type","reglist"=>"Accounts","simple_settings"=>"Settings","logout"=>"Log out");
		$menu[10] = array("start"=>"Home","info"=>"Info","kicklist"=>"Kick List","banlist"=>"Ban List","unbanlist"=>"Unban List","iplog"=>"IP-Log","stats"=>"Stats","filetrigger"=>"File Trigger","conntype"=>"Conn Type","reglist"=>"Accounts","simple_settings"=>"Settings","man"=>"Manager","logout"=>"Log out");
		//$plugins = array("isp"=>"ISP","chatroom"=>"!Chatroom","forbid"=>"!Forbid","messanger"=>"!Messanger","replace"=>"!Replace","plugman"=>"!Plugman");
		$plugins = array("isp"=>"-ISP-","plugman"=>"-Plugman-","chatroom"=>"-ChatRoom-","forbid"=>"-Forbid-","replacer"=>"-Replacer-","messanger"=>"-Messenger-");

		echo "<div id=\"menu\">
			<ul>";
		foreach($menu[USER_CLASS] as $link=>$name)
			{
				switch ($link)
				{
					case "filetrigger":
					echo "	<li><a href=\"?page=filetrigger\">File trigger</a>
							<ul>
							<li><a href=\"?page=filetrigger\">List</a></li>
							<li><a href=\"?page=addfiletrigger\">Add file trigger</a></li>
							</ul>		
						</li>";
					break;
	
					case "man":
					echo" <li><a href=\"#\">Manager</a>
						<ul>
						<li><a href=\"?page=mysql\">MySQL Man</a></li>
						<li><a href=\"?page=luaman\">LUA Man</a>
							<ul>
							<li><a href=\"?page=luawrite&method=new\">Write</a></li>
							<li><a href=\"?page=upload\">Upload</a></li>
							<li><a href=\"?page=luascript\">Edit</a></li>
							<li><a href=\"luaremove\">Delete</a></li>
							</ul>
						<li><a href=\"?page=conversion\">Reg Conversion</a></li>
						<li><a href=\"?page=log\">Log Manager</a></li>
						</ul>
						</li>";
					break;
					
					case "simple_settings":
					echo"<li><a href=\"?page=simple_settings\">Settings</a>
						<ul>
						<li><a href=\"?page=simple_settings\">Simple Settings</a></li>
						<li><a href=\"?page=settings\">Advanced Settings</a></li>
						<li><a href=\"?page=isp_settings\">ISP Settings</a></li>
						<li><a href=\"?page=forbid_settings\">Forbid Settings</a></li>
						<li><a href=\"?page=ezechiele_settings\">Ezechiele Settings</a>
							<ul>
							<li><a href=\"?page=junks\">Junk file list </a></li>
							<li><a href=\"?page=tthcoll\">TTH collection</a></li>
							<li><a href=\"?page=ezeconn\">Connection list</a></li>
							</ul>
						<li><a href=\"?page=vhcp_setting\">VHCP Settings</a>
						<li><a href=\"?page=lang\">Language Settings</a>
						</ul>	";
					break;

					case "reglist":
					echo "	<li><a href=\"?page=reglist\">Accounts</a>
							<ul>
							<li><a href=\"?page=reglist\">List</a></li>
							<li><a href=\"?page=adduser\">Add user</a></li>
							</ul>		
						</li>";
					break;

					case "conntype":
					echo "	<li><a href=\"?page=conntype\">Conn Type</a>
							<ul>
							<li><a href=\"?page=conntype\">List</a></li>
							<li><a href=\"?page=addconntype\">Add Conn Type</a></li>
							</ul>		
						</li>";
					break;
					default:
 	   					echo "<li><a href=\"?page=$link\">$name</a></li>";
 					break;
 				}
		}
		echo "</ul>
		</div>";
		if(USER_CLASS>=5)
		{
			
 			echo "<br />";
 			foreach($plugins as $link=>$name)
 			{
 				echo "<span class=\"menuplugin\"><a href=\"./?page=$link\">$name</a></span>\n";
 			}
		}
	}
	
	/**
    * Unix timestamp for a date
    * @param string $date the date to convert in Unix time format
    * @return int
   	* @access public
   	*/
	
	public function getUnixDate($date)
	{
		list ($day, $month, $year) = split ('[/.-]', $date);
		return mktime(0,0,0,$month,$day,$year);
	}
	
	/**
    * Return the kick/ban time
    * @param int $tban_kick duration of kick/ban
    * @param int $time time of kick/ban
   	* @return int
   	* @access public
   	*/
	
	public function kickTime($tban_kick,$time)
	{
		if ($tban_kick>= 60 && $tban_kick< 3600)
		{	
			$minutes = (int) floor ($tban_kick / 60); //minuti
			$min = date("i",$time) + $minutes;
			$seconds = $tban_kick % 60;
			$sec = date("s",$time) + $seconds;
			$ban_limit = "".date("d/m/Y",$time)." - ".date("H",$time).":".$min.":".$sec."";
			return $ban_limit;
			
		}
		if ($tban_kick>= 3600 && $tban_kick< 86400)
		{	
			$hours = (int) floor ($tban_kick / 3600); //ore
			$h = date("H",$time) + $hours;
			$minutes = $tban_kick % 3600;
			$min = date("i",$time) + $minutes;
			$ban_limit = "".date("d/m/Y",$time)." - ".$h.":".$min.":".date("s",$time)."";
			return $ban_limit;
			
		}
		if ($tban_kick>= 86400 && $tban_kick< 2678400)
		{	
			$days = (int) floor ($tban_kick / 86400); //ore
			$d = date("d",$time) + $days;
			$hours = $tban_kick % 86400;
			$h = date("H",$time) + $hours;
			$ban_limit = "".$d."/".date("m/Y",$time)." - ".$h.":".date("i",$time).":".date("s",$time)."";
			return $ban_limit;
			
		}
		return false;
	}
	
	/**
    * Print the number of pages
    * @param string $url the link
    * @param integer $page the current page
    * @param integer $pages the number of pages
    * @return void
   	* @access public
   	*/
	
	public function printPageMeny($url="./?",$page=1,$pages=1)
	{
		if($pages != 1 && $pages != 0)
		{
			echo "<div align=\"center\">Page/s [ ";
			for($i=1;$i<=$pages;$i++)
			{
				if($page==$i)
				{
					echo " <span class=\"page\">$i</span> ";
				}
				else
				{
					echo " <a href=\"$url$i\">$i</a> ";
				}
			}
			echo " ] </div> ";
		}
	}
	
	/**
    * Check if the access to the site is restricted to one or more ips
    * @param string $valid valid Ip
    * @return bool/string
   	* @access public
   	*/
	
	public function checkAccess($valid)
	{
		if($valid[0]=='all' || in_array($_SERVER['REMOTE_ADDR'],$valid))
		{
			return true;
		}
		else
		{
			Utility::error("You don't have access to visit this page.<br /> Your IP <i>{$_SERVER['REMOTE_ADDR']}</i>");
			die();
		}
	}
	
	/**
    * Return a message sent trought GET
    * @param array $array
    * @param string $message message that should be shown to the users
    * @param string $message_type type of message to show
    * @return void
   	* @access public
   	*/
	
	public function getMessage($array, $message, $message_type)
	{
		$print_message = array_search($message, $array);	
		if ($print_message != NULL OR $print_message) // Prior to PHP 4.2.0, array_search() returns NULL on failure instead of FALSE
		{
			if ($message_type == 'good') Utility::good($print_message);
			else Utility::error($print_message);
		}
	}
	
	/**
    * Return an message sent trought GET
    * @param array $selected_class array of the classes
    * @param integer $key the key of the array $field_type
    * @param string $option extra option for select tag
    * @global array $classes;
    * @deprecated
    * @return void
   	* @access public
   	*/
	
	public function ClassSelectMenu($selected_class,$key,$option="")
	{
		global $classes;
		$field_type = array(0=>'min_class',1=>'max_class',2=>'auto_class_min',3=>'auto_class_max',4=>'afclass',5=>'class',6=>'max_class_dest',7=>'max_check_conn_class');
		echo "<select name=\"$field_type[$key]\" $option>";
	
		foreach($classes as $class=>$name)
		{
			$selected = ($class==$selected_class) ? ' selected="selected"' : '';
			echo "        <option value=\"$class\"$selected>$class - $name </option>\n";
		}
	
	      echo '</select>';
		
	}
	
	/**
    * Return an message sent trought GET
    * @param array $selected_class array of the classes
    * @param string $field_name the name of select input
    * @global array $classes;
    * @todo must be re-written again; see ClassSelectMenu() 
    * @return void
   	* @access public
   	*/
	
	public function ClassSelectMenuImpo($selected_class,$field_name)
	{
		global $classes;
		echo "<select name=\"$field_name\">";
	
		foreach($classes as $class=>$name)
		{
			$selected = ($class==$selected_class) ? ' selected="selected"' : '';
			echo "        <option value=\"$class\"$selected>$class - $name </option>\n";
		}
	
	      echo '</select>';
		
	}
	/*
	public function ClassSelectMenu($selected_class,$fieldname,$option="")
	{
		global $classes;
		echo "<select name=\"$fieldname\" $option>";
	
		foreach($classes as $class=>$name)
		{
			$selected = ($class==$selected_class) ? ' selected="selected"' : '';
			echo "        <option value=\"$class\"$selected>$class - $name </option>\n";
		}
	
	      echo '</select>';
		
	}*/
	
	/**
    * Print a slect field where an user have to choose between Disable or Enable
    * @param string $var the variable
    * @param string $dbvar the field name
    * @param array $array
    * @param string $table_name optional table where to take the value
    * @access public
   	*/
	
	/*public function printSelect($var,$dbvar,$array=array("Disable","Enable"),$table_name='')
	{
		if ($table_name=='ezechiele') $var = Verlidb:: getConfig($var,false,'ezechiele');
		elseif ($table_name=='SetupList') $var = Verlidb:: getConfig($var);
		echo "	  <select name=\"$dbvar\">\n";
		foreach($array as $val=>$name)
		{
			$sel = ($var==$val) ? ' selected="selected"' : '';
			echo "	    <option value=\"$val\"$sel>$val - $name</option>\n";
		}
		echo "    </select>\n";
	}*/
	
	/**
    * Print an addy if a table exists
    * @param string $column table or column to check
    * @param string $address the addy to show
    * @param string $name the table's name
    * @param integer $flag a flag to choose between SetupList and other tables
    * @return void
    * @access public
   	*/
	
	public function checksettings($column,$address,$name,$config=false)
	{
		if (!$config)
		{
			if($q = MySQL::runQuery("SELECT * FROM `SetupList` where `file` = '$column' LIMIT 1",true)) echo "<a href=\"./?page=$address\"> $name settings</a> -";
		}
		else
		{	
			if($q = MySQL::runQuery("SELECT * FROM `$column` LIMIT 1",true))
			{
				echo "<a href=\"./?page=$address\"> $name settings</a> -";
			}
		}
		
	}
	
	/**
    * Show an help image that point to Verlihub-project.org's Wiki
    * @param string $name the table's name
    * @param int $flag a flag to choose between SetupList and other tables
    * @return void
    * @access public
   	*/
	
	public function showHelp()
	{
		global $helps;
		global $page_name;
		list($link, $description) = split('::',$helps[$page_name],2);
		echo "<a href=\"$link\" target=\"blank\" title=\"$description\"><img class=\"help\" src=\"./img/help.png\"></a>";
	}
	
	/**
    * Make a sum of the flags (forbid, filetrigger, etc.)
    * @param array $flags flags available
    * @return int
    * @access public
   	*/
	
	
	public function sumFlags($flags)
	{
		$flagdec = 0;
		foreach($flags as $flag)
		{
			if(isset($_POST[$flag]))
			{
				$flagdec += $flag;
			}
		}
		return intval($flagdec);
	}
	
	/**
    * Print a select input from a given Verli variable
    * @param string $cfg_name the name of the select input
    * @param string $table_name the table name from which gets the value
    * @param string $var the selected value in the select input
    * @param array $array the text to show in the select input
    * @return void
    * @access public
   	*/
	
	public function printSelect($cfg_name,$table_name='SetupList',$var='',$array=array("Disable","Enable"))
	{
		echo "	  <select name=\"$cfg_name\" style=\"width:130px;\">\n";
		if ($table_name == 'SetupList')	$cfg = Verlidb::getConfig($cfg_name);
		elseif ($table_name == 'ezechiele') $cfg = Verlidb::getConfig($cfg_name,$table_name);
		else $cfg = $var;
		foreach($array as $val=>$name)
		{
			$sel = ($cfg==$val) ? ' selected="selected"' : '';
			echo "	    <option value=\"$val\"$sel>$val - $name</option>\n";
		}
		echo "    </select>\n";
	}
	/**
    * Print a select input from a given value
    * @param string $var
    * @param string $dbvar the name of the select input
    * @param array $array the text to show in the select input
    * @return void
    * @access public
   	*/
	
	
	public function printSelect_general($var,$dbvar,$array=array("Disable","Enable"))
	{
		echo "	  <select name=\"$dbvar\">\n";
		foreach($array as $val=>$name)
		{
			$sel = ($var==$val) ? ' selected="selected"' : '';
			echo "	    <option value=\"$val\"$sel>$val - $name</option>\n";
		}
		echo "    </select>\n";
	}
	
	function Ezechielearray($cfg_name,$array=array("Disable","Enable"))
	{
		echo "	  <select name=\"$cfg_name\" style=\"width:130px;\">\n";
		$cfg = $this->ConfigEzechiele($cfg_name);
		foreach($array as $val=>$name)
		{
			$sel = ($cfg==$val) ? ' selected="selected"' : '';
			echo "	    <option value=\"$val\"$sel>$val - $name</option>\n";
		}
		echo "    </select>\n";
	}
	
	/**
    * Move and rename the temporary file uploaded; then print some information about that file like the temporary file name, the new uploaded file and the size. Then the temp file is removed
    * @param string $temp_file the temporary file
    * @param string $new_file the new file
    * @param boolean $description print or not some info
    * @return void
    * @access public
   	*/
	
	public function moveUploadedFile($temp_file,$new_file,$description = true)
	{
		copy($temp_file, $new_file);
		unlink($temp_file);
		if ($description)
		{
			echo "Temporary file name: ".$temp_file."<br>\n";
			echo "Uploaded file name: ".$new_file."<br>\n";
			echo "Size: ".filesize($new_file)."<br>\n";
		}
	}
	
	/**
    * Return the extention of a file
    * @param string $filename the file
    * @return string
    * @access public
   	*/
		
	public function getFileExtention($filename)
	{
		$tok = explode('.', $filename);
		return end($tok);
	}
}
?>